__author__ = 'viet.pham'
__copyright__ = 'GiQ GmbH'
__date__ = '22.09.2015'
__version__ = '0.0.6'
__status__ = 'beta'

from distutils.core import setup

setup(
    name='nagios',
    version='0.0.7',
    packages=['nagios'],
    url='',
    author='Viet Pham',
    author_email='viet.pham@getgoods.de',
    description='module to develop plugin for nagios, icinga.',
    keywords=['nagios', 'icinga', 'plugin'],
)
